+++
date = "2019-11-15"
weight = 100

title = "Binary Package Versioning"

aliases = [
    "/old-wiki/Build_and_Integration_infrastructure_documentation"
]
+++

# Understanding Build Suffixes

For every release (*Developer, Preview, Product*), we add a build suffix string
to the packages, which relates to the release name of Apertis.  The build
suffix gets added to every built .deb package. Having a build suffix helps
determine which Apertis release the .deb package was built for.

The suffix string is constructed of: `b<Release_Name>b<B_CNT>`.
- The initial `b` is for backward compatibility ensuring the new suffix string
  can work well together with older release packages.
- `<Release_Name>` refers to the Apertis release's name.
- `b<B_CNT>` refers to being a binary build along with the build count.

For example, for the Apertis Developer Release `v2020dev0` we add the string
`bv2020dev0b<B_CNT>` to the project configuration on OBS.  Similarly, for an
Apertis Product Release of `v2019.0` we add the string `bv2019.0b<B_CNT>` to
the project configuration on OBS.

## Point Releases

A point release rolls the packages previously released in the update and
security repositories into the stable branch. It is required to ensure that the
packages in the new point release have a higher version than the binary package
in the updates or security repositories, it is thus necessary to include the point
releases numbering (e.g. `v2019.1`, `v2019.2`) in the build suffix.

For example, during the initial release of the v2019 release, the build suffix
was `bv2019.0b<B_CNT>`. The same build suffix is inherited by the updates and
security sub-repositories during this time period. Before doing a new point
release *v2019.1*, the build suffix of the main repositories
(`apertis:v2019:target`, `apertis:v2019:development`, `apertis:v2019:sdk`,
`apertis:v2019:hmi` etc) is set to `vb2019.1b<B_CNT>`.

Once this step has been taken, changes previously commited to Apertis update
and security branches (such as `apertis/v2020-updates` and
`apertis/v2020-security`) are merged into the main release branch
(`apertis/v2020`), thus triggering a build and generation of a package with the
required point release suffix. This ensures that the packages synced from the
updates and security sub-repositories have higher versions than packages from
the updates and security sub-repositories. Once the merge has been completed,
the equivalent packages in the update and security branches are purged to allow
these branches to be used for following updates and security fixes to the new
point release.
